@@ -127,7 +127,12 @@ class ::Gdk::MiraclePainter
   # 必ず名前のあとにスクリーンネームを表示しなければいけない。
   # また、スクリーンネームの前には必ず @ が必要。
   def header_left_markup
-    Pango.parse_markup("<b>#{Pango.escape(message.user.name || '')}</b> @#{Pango.escape(message.user.idname)}")
+    user = message.user
+    if user.respond_to?(:idname)
+      Pango.parse_markup("<b>#{Pango.escape(user.name || '')}</b> @#{Pango.escape(user.idname)}")
+    else
+      Pango.parse_markup(Pango.escape(user.name || ''))
+    end
   end
 
   # 時刻の表記は必ず相対表記にしなければいけない。
